## CSS - Demos - Spinners

<script type="module" src="/web_components/js/css/demos/WebC__CSS__Demo__Spinners.mjs"></script>

<webc-container>
    <webc-css-demo-spinners        ></webc-css-demo-spinners> 
    <webc-css-demo-spinners no-css ></webc-css-demo-spinners>
    
</webc-container>